@@ -10,6 +10,7 @@
 #include <DStandardPaths>
 #include <DDesktopServices>
 #include <QRect>
+#include <QGuiApplication>
 #include <appinfo.h>
 #include <appmgr.h>
 
@@ -28,17 +29,7 @@ QString DesktopIntegration::currentDE()
 
 bool DesktopIntegration::isTreeLand()
 {
-    return qEnvironmentVariable("DDE_CURRENT_COMPOSITOR") == QStringLiteral("TreeLand");
-}
-
-void DesktopIntegration::openShutdownScreen()
-{
-    DDBusSender()
-        .service("org.deepin.dde.ShutdownFront1")
-        .interface("org.deepin.dde.ShutdownFront1")
-        .path("/org/deepin/dde/ShutdownFront1")
-        .method("Show")
-        .call();
+    return QGuiApplication::platformName() == "wayland";
 }
 
 void DesktopIntegration::openSystemSettings()
