@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ja">
 <context>
     <name>AppItemMenu</name>
     <message>
@@ -75,17 +77,17 @@
 <context>
     <name>BottomBar</name>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="33"/>
         <source>Power</source>
         <translation>電源</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="62"/>
         <source>Search</source>
         <translation>検索</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="109"/>
         <source>Full-screen Mode</source>
         <translation>全画面モード</translation>
     </message>
@@ -106,7 +108,7 @@
 <context>
     <name>FrequentlyUsedView</name>
     <message>
-        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="35"/>
+        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
         <source>Frequently Used</source>
         <translation>最近使用したもの</translation>
     </message>
@@ -114,7 +116,7 @@
 <context>
     <name>FullscreenFrame</name>
     <message>
-        <location filename="../qml/FullscreenFrame.qml" line="150"/>
+        <location filename="../qml/FullscreenFrame.qml" line="254"/>
         <source>Window Mode</source>
         <translation>ウィンドウ モード</translation>
     </message>
@@ -122,12 +124,12 @@
 <context>
     <name>LauncherController</name>
     <message>
-        <location filename="../launchercontroller.cpp" line="19"/>
+        <location filename="../launchercontroller.cpp" line="21"/>
         <source>Show launcher (hidden by default)</source>
         <translation>ランチャーを表示(デフォルトで非表示)</translation>
     </message>
     <message>
-        <location filename="../launchercontroller.cpp" line="20"/>
+        <location filename="../launchercontroller.cpp" line="22"/>
         <source>Toggle launcher visibility</source>
         <translation>ランチャーの可視性を切り替え</translation>
     </message>
@@ -161,7 +163,7 @@
     </message>
     <message>
         <location filename="../qml/Main.qml" line="32"/>
-        <source>Game</source>
+        <source>Games</source>
         <translation>ゲーム</translation>
     </message>
     <message>
@@ -190,17 +192,21 @@
         <translation>その他</translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="411"/>
-        <source>Are you sure you want to uninstall %1?</source>
-        <translation>%1 をアンインストールしてもよろしいですか？</translation>
+        <location filename="../qml/Main.qml" line="400"/>
+        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="423"/>
+        <source>Are you sure you want to uninstall %1?</source>
+        <translation type="vanished">%1 をアンインストールしてもよろしいですか？</translation>
+    </message>
+    <message>
+        <location filename="../qml/Main.qml" line="412"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="437"/>
+        <location filename="../qml/Main.qml" line="426"/>
         <source>Confirm</source>
         <translation>確認</translation>
     </message>
@@ -221,8 +227,8 @@
         <translation>すべてのアプリ</translation>
     </message>
     <message>
-        <location filename="../qml/FullscreenFrame.qml" line="566"/>
         <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
+        <location filename="../qml/FullscreenFrame.qml" line="557"/>
         <source>No search results</source>
         <translation>検索結果はありません</translation>
     </message>
@@ -250,29 +256,29 @@
         <translation>並び替えモード</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="144"/>
+        <location filename="../qml/windowed/SideBar.qml" line="145"/>
         <source>Computer</source>
         <translation>コンピューター</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="155"/>
+        <location filename="../qml/windowed/SideBar.qml" line="156"/>
         <source>Pictures</source>
         <translation>ピクチャー</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="166"/>
+        <location filename="../qml/windowed/SideBar.qml" line="167"/>
         <source>Documents</source>
         <translation>ドキュメント</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="177"/>
+        <location filename="../qml/windowed/SideBar.qml" line="178"/>
         <source>Desktop</source>
         <translation>デスクトップ</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="188"/>
+        <location filename="../qml/windowed/SideBar.qml" line="189"/>
         <source>Control Center</source>
         <translation>コントロールセンター</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
